@@ -301,8 +301,20 @@ class UdevadmDevice(object):
             if self.driver.startswith("rtsx"):
                 return "CARDREADER"
             if ((self._environment.get("DEVTYPE") not in ("disk", "partition")
-                    or 'ID_DRIVE_FLASH_SD' in self._environment)
+                    or 'ID_DRIVE_FLASH_SD' in self._environment
+                    or ('ID_MODEL' in self._environment
+                        and self._environment['ID_MODEL'] == 'Card_Reader'))
                     and self.driver == "sd" and self.product):
+                # The condition:
+                #     'ID_MODEL' in self._environment
+                #     and
+                #     self._environment['ID_MODEL'] == 'Card_Reader'
+                # is a workaround specific to LP: #1334224
+                # Otherwise, the card reader,
+                # 058f:6366 Alcor Micro Corp. Multi Flash Reader,
+                # of the system,
+                # CID 201009-6503 Dell Inspiron One 2310,
+                # will be given the category attribute 'DISK' by udev_resource
                 if any(FLASH_RE.search(k) for k in self._environment.keys()):
                     return "CARDREADER"
                 if any(d.bus == 'usb' for d in self._stack):
@@ -334,6 +346,10 @@ class UdevadmDevice(object):
                     return "CDROM"
                 if "ID_DRIVE_FLOPPY" in self._environment:
                     return "FLOPPY"
+                if self.driver == 'virtio_blk' and self.bus == 'virtio':
+                    # A QEMU/KVM virtual disk, but should be treated
+                    # as DISK nonetheless
+                    return "DISK"
             if devtype == "scsi_device":
                 match = SCSI_RE.match(self._environment.get("MODALIAS", ""))
                 type = int(match.group("type"), 16) if match else -1
@@ -643,6 +659,12 @@ class UdevadmParser(object):
         if device.bus == "net" and "ID_NET_NAME_MAC" in device._environment:
             return False
 
+        # Do not ignore QEMU/KVM virtio disks
+        if ("ID_PART_TABLE_TYPE" in device._environment and
+           device.bus == "virtio" and
+           device.driver == "virtio_blk"):
+            return False
+
         # Ignore devices without product AND vendor information
         if (device.product is None and device.product_id is None and
                 device.vendor is None and device.vendor_id is None):
